@@ -6,11 +6,12 @@ use Carp;
 use Class::Accessor::Chained::Fast;
 use Devel::ebug;
 use Term::ReadLine;
-use YAML;
+use YAML::Syck;
 use base qw(Class::Accessor::Chained::Fast);
 
 sub run {
   my $self = shift;
+  my $backend = shift;
 
   my $filename = join "", @ARGV;
 
@@ -20,6 +21,7 @@ sub run {
 
   my $ebug = Devel::ebug->new;
   $ebug->program($filename);
+  $ebug->backend($backend);
   $ebug->load;
 
   my $codelines;
